{image alt="ducks" file-path="http://placehold.it/350x150" caption="true" source="https://placehold.it/" hover-text="This is hover text" alignment="left"}

{image alt="dogs" file-path="http://placehold.it/350x150" caption="true" source="https://placehold.it/" alignment="left"}

This is the second caption.

{image end}

This is a caption.

{image end}
